@@ -67,7 +67,34 @@ class Calculator:
     score: Optional[int]  # Only relevant for osu!mania
 
     def __init__(self, data: Optional[Dict[str, Union[int, float, None]]] = None, **kwargs) -> 'Calculator':
-        '''Create new Calculator'''
+        '''
+        Create new Calculator
+
+        ## Attrs:
+
+        `mode`: `Optional[int]` # gamemode convert
+
+        `mods`: `Optional[int]`
+
+        `n50`: `Optional[int]` # Irrelevant for osu!mania
+
+        `n100`: `Optional[int]` # Irrelevant for osu!mania and osu!taiko
+
+        `n300`: `Optional[int]` # Irrelevant for osu!mania
+
+        `katu`: `Optional[int]` # Only relevant for osu!ctb
+
+        `acc`: `Optional[float]` # Irrelevant for osu!mania
+
+        `passed_obj`: `Optional[int]` 
+
+        `combo`: `Optional[int]` # Irrelevant for osu!mania
+
+        `miss`: `Optional[int]` # Irrelevant for osu!mania
+
+        `score`: `Optional[int]` # Only relevant for osu!mania
+
+        '''
         self._raw = _pp_rust.Calculator()
         set = data or kwargs
         if set:
@@ -137,63 +164,63 @@ class Calculator:
         return CalcResult(self._raw.calculate(beatmap._raw))
 
     # Interfaces -----
-    def set_mode(val: Optional[int]) -> None: ...
-    def set_mods(val: Optional[int]) -> None: ...
+    def set_mode(self, val: Optional[int]) -> None: ...
+    def set_mods(self, val: Optional[int]) -> None: ...
 
-    def set_n50(val: Optional[int]) -> None:
+    def set_n50(self, val: Optional[int]) -> None:
         '''### Irrelevant for osu!mania'''
         ...
 
-    def set_n100(val: Optional[int]) -> None:
+    def set_n100(self, val: Optional[int]) -> None:
         '''### Irrelevant for osu!mania and osu!taiko'''
         ...
 
-    def set_n300(val: Optional[int]) -> None:
+    def set_n300(self, val: Optional[int]) -> None:
         '''### Irrelevant for osu!mania'''
         ...
 
-    def set_katu(val: Optional[int]) -> None:
+    def set_katu(self, val: Optional[int]) -> None:
         '''### Only relevant for osu!ctb'''
         ...
 
-    def set_acc(val: Optional[float]) -> None:
+    def set_acc(self, val: Optional[float]) -> None:
         '''### Irrelevant for osu!mania'''
         ...
 
-    def set_passed_obj(val: Optional[int]) -> None: ...
+    def set_passed_obj(self, val: Optional[int]) -> None: ...
 
-    def set_combo(val: Optional[int]) -> None:
+    def set_combo(self, val: Optional[int]) -> None:
         '''### Irrelevant for osu!mania'''
         ...
 
-    def set_miss(val: Optional[int]) -> None:
+    def set_miss(self, val: Optional[int]) -> None:
         '''### Irrelevant for osu!mania'''
         ...
 
-    def set_score(val: Optional[int]) -> None:
+    def set_score(self, val: Optional[int]) -> None:
         '''### Only relevant for osu!mania'''
         ...
 
-    def del_mode() -> None: ...
-    def del_mods() -> None: ...
-    def del_n50() -> None: ...
-    def del_n100() -> None: ...
-    def del_n300() -> None: ...
-    def del_katu() -> None: ...
-    def del_acc() -> None: ...
-    def del_passed_obj() -> None: ...
-    def del_combo() -> None: ...
-    def del_miss() -> None: ...
-    def del_score() -> None: ...
+    def del_mode(self) -> None: ...
+    def del_mods(self) -> None: ...
+    def del_n50(self) -> None: ...
+    def del_n100(self) -> None: ...
+    def del_n300(self) -> None: ...
+    def del_katu(self) -> None: ...
+    def del_acc(self) -> None: ...
+    def del_passed_obj(self) -> None: ...
+    def del_combo(self) -> None: ...
+    def del_miss(self) -> None: ...
+    def del_score(self) -> None: ...
 
-    def get_mode(val: Optional[int]) -> Optional[int]: ...
-    def get_mods(val: Optional[int]) -> Optional[int]: ...
-    def get_n50(val: Optional[int]) -> Optional[int]: ...
-    def get_n100(val: Optional[int]) -> Optional[int]: ...
-    def get_n300(val: Optional[int]) -> Optional[int]: ...
-    def get_katu(val: Optional[int]) -> Optional[int]: ...
-    def get_acc(val: Optional[float]) -> Optional[float]: ...
-    def get_passed_obj(val: Optional[int]) -> Optional[int]: ...
-    def get_combo(val: Optional[int]) -> Optional[int]: ...
-    def get_miss(val: Optional[int]) -> Optional[int]: ...
-    def get_score(val: Optional[int]) -> Optional[int]: ...
+    def get_mode(self) -> Optional[int]: ...
+    def get_mods(self) -> Optional[int]: ...
+    def get_n50(self) -> Optional[int]: ...
+    def get_n100(self) -> Optional[int]: ...
+    def get_n300(self) -> Optional[int]: ...
+    def get_katu(self) -> Optional[int]: ...
+    def get_acc(self) -> Optional[float]: ...
+    def get_passed_obj(self) -> Optional[int]: ...
+    def get_combo(self) -> Optional[int]: ...
+    def get_miss(self) -> Optional[int]: ...
+    def get_score(self) -> Optional[int]: ...
